@@ -1,8 +1,5 @@
-"""
-(c) Dativa 2012-2020, all rights reserved
-
-This code is licensed under MIT license (see license.txt for details)
-"""
+# (c) Deductive 2012-2020, all rights reserved
+# This code is licensed under MIT license (see license.txt for details)
 
 from urllib import parse
 
@@ -12,21 +9,24 @@ class S3Location(str):
     Class that parses out an S3 location from a passed string. Subclass of `str`
     so supports most string operations.
 
-    Also contains properties .bucket, .key, .path, .prefix and method .join()
-
     :param s3_str: string representation of s3 location, accepts most common formats
-        eg:
-            - 's3://bucket/folder/file.txt'
-            - 'bucket/folder'
-            - 'http[s]://s3*.amazonaws.com/bucket-name/'
-        also accepts None if using `bucket` and `key` keywords
+        Also accepts None if using `bucket` and `key` keywords
     :param bucket: ignored if s3_str is not None. can specify only bucket for
         bucket='mybucket' - 's3://mybucket/' or in conjuction with `key`
     :param key: ignored if s3_str is not None. Bucket must be set.
-        bucket='mybucket', key='path/to/file' - 's3://mybucket/path/to/file'
+        bucket='mybucket', key='path/to/file'
     :param ignore_double_slash: default False. If true allows s3 locations containing '//'
         these are valid s3 paths, but typically result from mistaken joins
 
+    Examples:
+
+    .. code-block:: python
+
+        loc1 = S3Location('s3://bucket/folder/file.txt')
+        loc2 = S3Location('bucket/folder')
+        loc3 = S3Location('http://s3*.amazonaws.com/bucket-name/')
+        loc4 = S3Location('https://s3*.amazonaws.com/bucket-name/')
+        loc5 = S3Location(bucket='bucket', key='path/to/file')
 
 
     """
@@ -117,42 +117,65 @@ class S3Location(str):
 
     @property
     def file(self):
+        """
+        File property
+        :return: the file name part of the S3 URL
+        """
         return self._coalesce_empty(self._key.split("/")[-1], None)
 
     @property
     def prefix(self):
+        """
 
+        :return: the prefix part of the S3 URL
+        """
         return self._coalesce_empty("/".join(self._key.split("/")[0:-1]), None)
 
     @property
     def key(self):
+        """
 
+        :return: the key part of the S3 URL
+        """
         return self._coalesce_empty(self._key, None)
 
     @property
     def path(self):
+        """
+
+        :return: the path part of the S3 URL (same as the key)
+        """
         return self.key
 
     @property
     def bucket(self):
+        """
+
+        :return: the bucket part of the S3 URL (same as the key)
+        """
         return self._coalesce_empty(self._bucket, None)
 
     @property
     def s3_url(self):
-        """deprecated - can use str, or in most cases simply the object itself"""
         return "s3://{bucket}/{path}".format(bucket=self.bucket,
                                              path=self.key or '')
 
     def join(self, *other, ignore_double_slash=False):
         """
         Join s3 location to string or list of strings similar to os.path.join
-        eg.
-            - s3.join('file')
-            - s3.join('path', 'to', 'file')
         :param other: nargs to join,
-        :param ignore_double_slash: default False. set true to allow '//' in the link, eg
-            's3://bucket/folder//path/key'.
-        :return: S3Location
+        :param ignore_double_slash: default False. set true to allow '//' in the link, eg 's3://bucket/folder//path/key'
+        :return: the new S3Location
+
+        Examples:
+
+        .. code-block:: python
+
+            loc1 = S3Location('s3://bucket/folder/')
+            loc2 = loc1.join('file.txt')
+            loc3 = loc1.join('path', 'to', 'file')
+
+
         """
 
         to_join = '/'.join(other)
