@@ -105,7 +105,7 @@ class PandasDoggo:
 
         if path.endswith('.gzip') or path.endswith('.gz'):
             return 'gzip'
-        if ('.snappy.' in path) or ('.sz.' in path):
+        if ('.snappy' in path) or path.endswith('.sz'):
             return 'snappy'
         if path.endswith('.zip'):
             return 'zip'
